==> jei-1.19.4-fabric-13.1.0.8-sources.jar: mezz/jei/common/gui/elements/DrawableResource.java <==
package mezz.jei.common.gui.elements;

import com.mojang.blaze3d.systems.RenderSystem;
import mezz.jei.api.gui.drawable.IDrawableStatic;
import net.minecraft.class_287;
import net.minecraft.class_289;
import net.minecraft.class_290;
import net.minecraft.class_293;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_757;
import org.joml.Matrix4f;

public class DrawableResource implements IDrawableStatic {

	private final class_2960 resourceLocation;
	private final int textureWidth;
	private final int textureHeight;

	private final int u;
	private final int v;
	private final int width;
	private final int height;
	private final int paddingTop;
	private final int paddingBottom;
	private final int paddingLeft;
	private final int paddingRight;

	public DrawableResource(class_2960 resourceLocation, int u, int v, int width, int height, int paddingTop, int paddingBottom, int paddingLeft, int paddingRight, int textureWidth, int textureHeight) {
		this.resourceLocation = resourceLocation;
		this.textureWidth = textureWidth;
		this.textureHeight = textureHeight;

		this.u = u;
		this.v = v;
		this.width = width;
		this.height = height;

		this.paddingTop = paddingTop;
		this.paddingBottom = paddingBottom;
		this.paddingLeft = paddingLeft;
		this.paddingRight = paddingRight;
	}

	@Override
	public int getWidth() {
		return width + paddingLeft + paddingRight;
	}

	@Override
	public int getHeight() {
		return height + paddingTop + paddingBottom;
	}

	@Override
	public void draw(class_4587 poseStack, int xOffset, int yOffset) {
		draw(poseStack, xOffset, yOffset, 0, 0, 0, 0);
	}

	@Override
	public void draw(class_4587 poseStack, int xOffset, int yOffset, int maskTop, int maskBottom, int maskLeft, int maskRight) {
		RenderSystem.setShader(class_757::method_34542);
		RenderSystem.setShaderTexture(0, this.resourceLocation);

		int x = xOffset + this.paddingLeft + maskLeft;
		int y = yOffset + this.paddingTop + maskTop;
		int u = this.u + maskLeft;
		int v = this.v + maskTop;
		int width = this.width - maskRight - maskLeft;
		int height = this.height - maskBottom - maskTop;
		float f = 1.0F / this.textureWidth;
		float f1 = 1.0F / this.textureHeight;
		class_289 tessellator = class_289.method_1348();
		class_287 bufferbuilder = tessellator.method_1349();
		bufferbuilder.method_1328(class_293.class_5596.field_27382, class_290.field_1585);
		Matrix4f matrix = poseStack.method_23760().method_23761();
		bufferbuilder.method_22918(matrix, x, y + height, 0).method_22913(u * f, (v + (float) height) * f1).method_1344();
		bufferbuilder.method_22918(matrix, x + width, y + height, 0).method_22913((u + (float) width) * f, (v + (float) height) * f1).method_1344();
		bufferbuilder.method_22918(matrix, x + width, y, 0).method_22913((u + (float) width) * f, v * f1).method_1344();
		bufferbuilder.method_22918(matrix, x, y, 0).method_22913(u * f, v * f1).method_1344();
		tessellator.method_1350();
	}
}

==> jei-1.20.1-fabric-15.20.0.125-sources.jar: mezz/jei/common/gui/elements/DrawableResource.java <==
package mezz.jei.common.gui.elements;

import com.mojang.blaze3d.systems.RenderSystem;
import mezz.jei.api.gui.drawable.IDrawableStatic;
import net.minecraft.class_287;
import net.minecraft.class_289;
import net.minecraft.class_290;
import net.minecraft.class_293;
import net.minecraft.class_2960;
import net.minecraft.class_332;
import net.minecraft.class_757;
import org.joml.Matrix4f;

public class DrawableResource implements IDrawableStatic {

	private final class_2960 resourceLocation;
	private final int textureWidth;
	private final int textureHeight;

	private final int u;
	private final int v;
	private final int width;
	private final int height;
	private final int paddingTop;
	private final int paddingBottom;
	private final int paddingLeft;
	private final int paddingRight;

	public DrawableResource(class_2960 resourceLocation, int u, int v, int width, int height, int paddingTop, int paddingBottom, int paddingLeft, int paddingRight, int textureWidth, int textureHeight) {
		this.resourceLocation = resourceLocation;
		this.textureWidth = textureWidth;
		this.textureHeight = textureHeight;

		this.u = u;
		this.v = v;
		this.width = width;
		this.height = height;

		this.paddingTop = paddingTop;
		this.paddingBottom = paddingBottom;
		this.paddingLeft = paddingLeft;
		this.paddingRight = paddingRight;
	}

	@Override
	public int getWidth() {
		return width + paddingLeft + paddingRight;
	}

	@Override
	public int getHeight() {
		return height + paddingTop + paddingBottom;
	}

	@Override
	public void draw(class_332 guiGraphics, int xOffset, int yOffset) {
		draw(guiGraphics, xOffset, yOffset, 0, 0, 0, 0);
	}

	@Override
	public void draw(class_332 guiGraphics, int xOffset, int yOffset, int maskTop, int maskBottom, int maskLeft, int maskRight) {
		RenderSystem.setShader(class_757::method_34542);
		RenderSystem.setShaderTexture(0, this.resourceLocation);

		int x = xOffset + this.paddingLeft + maskLeft;
		int y = yOffset + this.paddingTop + maskTop;
		int u = this.u + maskLeft;
		int v = this.v + maskTop;
		int width = this.width - maskRight - maskLeft;
		int height = this.height - maskBottom - maskTop;
		float f = 1.0F / this.textureWidth;
		float f1 = 1.0F / this.textureHeight;
		class_289 tessellator = class_289.method_1348();
		class_287 bufferbuilder = tessellator.method_1349();
		bufferbuilder.method_1328(class_293.class_5596.field_27382, class_290.field_1585);
		Matrix4f matrix = guiGraphics.method_51448().method_23760().method_23761();
		bufferbuilder.method_22918(matrix, x, y + height, 0).method_22913(u * f, (v + (float) height) * f1).method_1344();
		bufferbuilder.method_22918(matrix, x + width, y + height, 0).method_22913((u + (float) width) * f, (v + (float) height) * f1).method_1344();
		bufferbuilder.method_22918(matrix, x + width, y, 0).method_22913((u + (float) width) * f, v * f1).method_1344();
		bufferbuilder.method_22918(matrix, x, y, 0).method_22913(u * f, v * f1).method_1344();
		tessellator.method_1350();
	}
}
